import { EscrowClient } from '..';
import { EventEmitter } from './Emitter.js';
import { MemberController } from './Admin.js';
import { ContractParser } from './Parser.js';
import { ProposalController } from './Proposal.js';
import { SignatureController } from './Signature.js';
import { ContractConfig, ContractCreate, ContractData, AgentData, DepositData, ProposeData, SignatureData, TransactionData } from '../schema/index.js';
import { TermController } from './Terms';
export declare class EscrowContract extends EventEmitter {
    static create(client: EscrowClient, template: ContractCreate, config?: Partial<ContractConfig>): Promise<EscrowContract>;
    readonly _cid: string;
    readonly _client: EscrowClient;
    readonly _parser: ContractParser;
    readonly config: ContractConfig;
    _cache?: ContractData;
    refreshed_at?: Date;
    constructor(client: EscrowClient, contract: ContractData, config?: Partial<ContractConfig>);
    get id(): string;
    get API(): import("../routes/contract").ContractRouter;
    get pubkey(): string;
    get data(): Promise<ContractData>;
    get agent(): Promise<AgentData>;
    get deposts(): Promise<DepositData[]>;
    get members(): Promise<string[]>;
    get proposals(): Promise<ProposeData[]>;
    get signatures(): Promise<SignatureData[]>;
    get transactions(): Promise<TransactionData[]>;
    cache(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        members: string[];
        created_at: number;
        updated_at: number;
        title: string;
        desc: string;
        cid: string;
        agent: {
            pubkey: string;
            nonce: string;
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
        };
        deposits: {
            value: number;
            txid: string;
            vout: number;
        }[];
        proposals: {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            };
            created_at: number;
            id: string;
        }[];
        session: {
            scripts: string[][];
            secret: string;
            pubkeys: string[];
            nonces: string[];
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }[];
        transactions: {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }[];
    }>;
    fetch(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        members: string[];
        created_at: number;
        updated_at: number;
        title: string;
        desc: string;
        cid: string;
        agent: {
            pubkey: string;
            nonce: string;
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
        };
        deposits: {
            value: number;
            txid: string;
            vout: number;
        }[];
        proposals: {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            };
            created_at: number;
            id: string;
        }[];
        session: {
            scripts: string[][];
            secret: string;
            pubkeys: string[];
            nonces: string[];
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }[];
        transactions: {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }[];
    }>;
    member: MemberController;
    proposal: ProposalController;
    signature: SignatureController;
    terms: TermController;
}
//# sourceMappingURL=Contract.d.ts.map