import { ProfileRouter } from '../routes/propose.js';
import { EscrowContract } from './Contract.js';
import { DetailData, PayoutData, ProposeData, ProposeTemplate, RecordData, ScriptData } from '../schema/index.js';
export declare class TermController {
    readonly _contract: EscrowContract;
    constructor(contract: EscrowContract);
    get API(): ProfileRouter;
    get id(): string;
    get pubkey(): string;
    get data(): Promise<ProposeData | undefined>;
    refresh(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        members: string[];
        created_at: number;
        updated_at: number;
        title: string;
        desc: string;
        cid: string;
        agent: {
            pubkey: string;
            nonce: string;
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
        };
        deposits: {
            value: number;
            txid: string;
            vout: number;
        }[];
        proposals: {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            };
            created_at: number;
            id: string;
        }[];
        session: {
            scripts: string[][];
            secret: string;
            pubkeys: string[];
            nonces: string[];
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }[];
        transactions: {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }[];
    }>;
    list(): Promise<ProposeData[]>;
    update(template: ProposeTemplate): Promise<{
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
            details: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            };
            payments: {
                value: number;
                address: string;
                label: string;
            }[];
            returns: {
                value: number;
                address: string;
                label: string;
            }[];
            records: {
                label: string;
                content: string;
            }[];
            scripts: {
                label: string;
                script: string[];
            }[];
        };
        created_at: number;
        id: string;
    } | undefined>;
    remove(): Promise<{
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
            details: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            };
            payments: {
                value: number;
                address: string;
                label: string;
            }[];
            returns: {
                value: number;
                address: string;
                label: string;
            }[];
            records: {
                label: string;
                content: string;
            }[];
            scripts: {
                label: string;
                script: string[];
            }[];
        };
        created_at: number;
        id: string;
    } | undefined>;
    getDetails(): Promise<Partial<DetailData>[]>;
    getFees(): Promise<PayoutData[]>;
    getPayments(): Promise<PayoutData[]>;
    getReturns(): Promise<PayoutData[]>;
    getRecords(): Promise<RecordData[]>;
    getScripts(): Promise<ScriptData[]>;
}
//# sourceMappingURL=Terms.d.ts.map