import { z } from 'zod';
export type ContractCreate = z.infer<typeof create>;
export type ContractData = z.infer<typeof data>;
export type ContractTemplate = z.infer<typeof template>;
declare const template: z.ZodObject<{
    title: z.ZodString;
    desc: z.ZodDefault<z.ZodString>;
    members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
}, "strip", z.ZodTypeAny, {
    members: string[];
    title: string;
    desc: string;
}, {
    title: string;
    desc?: string | undefined;
    members?: string[] | undefined;
}>;
declare const create: z.ZodObject<{
    members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    title: z.ZodString;
    desc: z.ZodDefault<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    members: string[];
    title: string;
    desc: string;
}, {
    title: string;
    members?: string[] | undefined;
    desc?: string | undefined;
}>;
declare const data: z.ZodObject<{
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    created_at: z.ZodNumber;
    updated_at: z.ZodNumber;
    title: z.ZodString;
    desc: z.ZodDefault<z.ZodString>;
    cid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    agent: z.ZodObject<{
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        fees: z.ZodDefault<z.ZodArray<z.ZodObject<{
            address: z.ZodString;
            label: z.ZodString;
            value: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            value: number;
            address: string;
            label: string;
        }, {
            value: number;
            address: string;
            label: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        fees: {
            value: number;
            address: string;
            label: string;
        }[];
    }, {
        pubkey: string;
        nonce: string;
        fees?: {
            value: number;
            address: string;
            label: string;
        }[] | undefined;
    }>;
    deposits: z.ZodDefault<z.ZodArray<z.ZodObject<{
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        vout: z.ZodNumber;
        value: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        value: number;
        txid: string;
        vout: number;
    }, {
        value: number;
        txid: string;
        vout: number;
    }>, "many">>;
    proposals: z.ZodDefault<z.ZodArray<z.ZodObject<{
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        alias: z.ZodString;
        terms: z.ZodObject<{
            details: z.ZodDefault<z.ZodObject<{
                expires: z.ZodOptional<z.ZodDefault<z.ZodNumber>>;
                quorum: z.ZodOptional<z.ZodOptional<z.ZodObject<{
                    members: z.ZodOptional<z.ZodArray<z.ZodTuple<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodDefault<z.ZodNumber>], null>, "many">>;
                    size: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                }, {
                    members?: [string, number | undefined][] | undefined;
                    size?: number | undefined;
                }>>>;
                return: z.ZodOptional<z.ZodString>;
                value: z.ZodOptional<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            }, {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number | undefined][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            }>>;
            fees: z.ZodDefault<z.ZodArray<z.ZodObject<{
                address: z.ZodString;
                label: z.ZodString;
                value: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                value: number;
                address: string;
                label: string;
            }, {
                value: number;
                address: string;
                label: string;
            }>, "many">>;
            payments: z.ZodDefault<z.ZodArray<z.ZodObject<{
                address: z.ZodString;
                label: z.ZodString;
                value: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                value: number;
                address: string;
                label: string;
            }, {
                value: number;
                address: string;
                label: string;
            }>, "many">>;
            returns: z.ZodDefault<z.ZodArray<z.ZodObject<{
                address: z.ZodString;
                label: z.ZodString;
                value: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                value: number;
                address: string;
                label: string;
            }, {
                value: number;
                address: string;
                label: string;
            }>, "many">>;
            records: z.ZodDefault<z.ZodArray<z.ZodObject<{
                label: z.ZodString;
                content: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                label: string;
                content: string;
            }, {
                label: string;
                content: string;
            }>, "many">>;
            scripts: z.ZodDefault<z.ZodArray<z.ZodObject<{
                label: z.ZodString;
                script: z.ZodArray<z.ZodString, "many">;
            }, "strip", z.ZodTypeAny, {
                label: string;
                script: string[];
            }, {
                label: string;
                script: string[];
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
            details: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            };
            payments: {
                value: number;
                address: string;
                label: string;
            }[];
            returns: {
                value: number;
                address: string;
                label: string;
            }[];
            records: {
                label: string;
                content: string;
            }[];
            scripts: {
                label: string;
                script: string[];
            }[];
        }, {
            details?: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number | undefined][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            } | undefined;
            fees?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            payments?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            returns?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            records?: {
                label: string;
                content: string;
            }[] | undefined;
            scripts?: {
                label: string;
                script: string[];
            }[] | undefined;
        }>;
        created_at: z.ZodDefault<z.ZodNumber>;
        id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
            details: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            };
            payments: {
                value: number;
                address: string;
                label: string;
            }[];
            returns: {
                value: number;
                address: string;
                label: string;
            }[];
            records: {
                label: string;
                content: string;
            }[];
            scripts: {
                label: string;
                script: string[];
            }[];
        };
        created_at: number;
        id: string;
    }, {
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            details?: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number | undefined][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            } | undefined;
            fees?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            payments?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            returns?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            records?: {
                label: string;
                content: string;
            }[] | undefined;
            scripts?: {
                label: string;
                script: string[];
            }[] | undefined;
        };
        id: string;
        created_at?: number | undefined;
    }>, "many">>;
    session: z.ZodObject<{
        secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkeys: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
        nonces: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
        scripts: z.ZodDefault<z.ZodArray<z.ZodArray<z.ZodString, "many">, "many">>;
        sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        taproot: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        txdata: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
    }, "strip", z.ZodTypeAny, {
        scripts: string[][];
        secret: string;
        pubkeys: string[];
        nonces: string[];
        sighash?: string | undefined;
        taproot?: string | undefined;
        txdata?: string | undefined;
    }, {
        secret: string;
        pubkeys?: string[] | undefined;
        nonces?: string[] | undefined;
        scripts?: string[][] | undefined;
        sighash?: string | undefined;
        taproot?: string | undefined;
        txdata?: string | undefined;
    }>;
    signatures: z.ZodDefault<z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        kind: z.ZodEnum<["claim", "close", "vote"]>;
        psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        hash: string;
        kind: "claim" | "close" | "vote";
        psig: string;
    }, {
        pubkey: string;
        hash: string;
        kind: "claim" | "close" | "vote";
        psig: string;
    }>, "many">>;
    transactions: z.ZodDefault<z.ZodArray<z.ZodObject<{
        confirmed: z.ZodBoolean;
        height: z.ZodNumber;
        kind: z.ZodEnum<["deposit", "script", "spend"]>;
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        txdata: z.ZodEffects<z.ZodString, string, string>;
        updated_at: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        txid: string;
        txdata: string;
        kind: "script" | "deposit" | "spend";
        confirmed: boolean;
        height: number;
        updated_at: number;
    }, {
        txid: string;
        txdata: string;
        kind: "script" | "deposit" | "spend";
        confirmed: boolean;
        height: number;
        updated_at: number;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    members: string[];
    created_at: number;
    updated_at: number;
    title: string;
    desc: string;
    cid: string;
    agent: {
        pubkey: string;
        nonce: string;
        fees: {
            value: number;
            address: string;
            label: string;
        }[];
    };
    deposits: {
        value: number;
        txid: string;
        vout: number;
    }[];
    proposals: {
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
            details: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            };
            payments: {
                value: number;
                address: string;
                label: string;
            }[];
            returns: {
                value: number;
                address: string;
                label: string;
            }[];
            records: {
                label: string;
                content: string;
            }[];
            scripts: {
                label: string;
                script: string[];
            }[];
        };
        created_at: number;
        id: string;
    }[];
    session: {
        scripts: string[][];
        secret: string;
        pubkeys: string[];
        nonces: string[];
        sighash?: string | undefined;
        taproot?: string | undefined;
        txdata?: string | undefined;
    };
    signatures: {
        pubkey: string;
        hash: string;
        kind: "claim" | "close" | "vote";
        psig: string;
    }[];
    transactions: {
        txid: string;
        txdata: string;
        kind: "script" | "deposit" | "spend";
        confirmed: boolean;
        height: number;
        updated_at: number;
    }[];
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    created_at: number;
    updated_at: number;
    title: string;
    cid: string;
    agent: {
        pubkey: string;
        nonce: string;
        fees?: {
            value: number;
            address: string;
            label: string;
        }[] | undefined;
    };
    session: {
        secret: string;
        pubkeys?: string[] | undefined;
        nonces?: string[] | undefined;
        scripts?: string[][] | undefined;
        sighash?: string | undefined;
        taproot?: string | undefined;
        txdata?: string | undefined;
    };
    members?: string[] | undefined;
    desc?: string | undefined;
    deposits?: {
        value: number;
        txid: string;
        vout: number;
    }[] | undefined;
    proposals?: {
        pubkey: string;
        sig: string;
        nonce: string;
        alias: string;
        terms: {
            details?: {
                expires?: number | undefined;
                quorum?: {
                    members?: [string, number | undefined][] | undefined;
                    size?: number | undefined;
                } | undefined;
                return?: string | undefined;
                value?: number | undefined;
            } | undefined;
            fees?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            payments?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            returns?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
            records?: {
                label: string;
                content: string;
            }[] | undefined;
            scripts?: {
                label: string;
                script: string[];
            }[] | undefined;
        };
        id: string;
        created_at?: number | undefined;
    }[] | undefined;
    signatures?: {
        pubkey: string;
        hash: string;
        kind: "claim" | "close" | "vote";
        psig: string;
    }[] | undefined;
    transactions?: {
        txid: string;
        txdata: string;
        kind: "script" | "deposit" | "spend";
        confirmed: boolean;
        height: number;
        updated_at: number;
    }[] | undefined;
}>;
export declare const ContractSchema: {
    create: z.ZodObject<{
        members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
        title: z.ZodString;
        desc: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        members: string[];
        title: string;
        desc: string;
    }, {
        title: string;
        members?: string[] | undefined;
        desc?: string | undefined;
    }>;
    data: z.ZodObject<{
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
        created_at: z.ZodNumber;
        updated_at: z.ZodNumber;
        title: z.ZodString;
        desc: z.ZodDefault<z.ZodString>;
        cid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        agent: z.ZodObject<{
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            fees: z.ZodDefault<z.ZodArray<z.ZodObject<{
                address: z.ZodString;
                label: z.ZodString;
                value: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                value: number;
                address: string;
                label: string;
            }, {
                value: number;
                address: string;
                label: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            nonce: string;
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
        }, {
            pubkey: string;
            nonce: string;
            fees?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
        }>;
        deposits: z.ZodDefault<z.ZodArray<z.ZodObject<{
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            vout: z.ZodNumber;
            value: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            value: number;
            txid: string;
            vout: number;
        }, {
            value: number;
            txid: string;
            vout: number;
        }>, "many">>;
        proposals: z.ZodDefault<z.ZodArray<z.ZodObject<{
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            alias: z.ZodString;
            terms: z.ZodObject<{
                details: z.ZodDefault<z.ZodObject<{
                    expires: z.ZodOptional<z.ZodDefault<z.ZodNumber>>;
                    quorum: z.ZodOptional<z.ZodOptional<z.ZodObject<{
                        members: z.ZodOptional<z.ZodArray<z.ZodTuple<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodDefault<z.ZodNumber>], null>, "many">>;
                        size: z.ZodOptional<z.ZodNumber>;
                    }, "strip", z.ZodTypeAny, {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    }, {
                        members?: [string, number | undefined][] | undefined;
                        size?: number | undefined;
                    }>>>;
                    return: z.ZodOptional<z.ZodString>;
                    value: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                }, {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number | undefined][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                }>>;
                fees: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    address: z.ZodString;
                    label: z.ZodString;
                    value: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    value: number;
                    address: string;
                    label: string;
                }, {
                    value: number;
                    address: string;
                    label: string;
                }>, "many">>;
                payments: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    address: z.ZodString;
                    label: z.ZodString;
                    value: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    value: number;
                    address: string;
                    label: string;
                }, {
                    value: number;
                    address: string;
                    label: string;
                }>, "many">>;
                returns: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    address: z.ZodString;
                    label: z.ZodString;
                    value: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    value: number;
                    address: string;
                    label: string;
                }, {
                    value: number;
                    address: string;
                    label: string;
                }>, "many">>;
                records: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    label: z.ZodString;
                    content: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    content: string;
                }, {
                    label: string;
                    content: string;
                }>, "many">>;
                scripts: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    label: z.ZodString;
                    script: z.ZodArray<z.ZodString, "many">;
                }, "strip", z.ZodTypeAny, {
                    label: string;
                    script: string[];
                }, {
                    label: string;
                    script: string[];
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            }, {
                details?: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number | undefined][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                } | undefined;
                fees?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                payments?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                returns?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                records?: {
                    label: string;
                    content: string;
                }[] | undefined;
                scripts?: {
                    label: string;
                    script: string[];
                }[] | undefined;
            }>;
            created_at: z.ZodDefault<z.ZodNumber>;
            id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            };
            created_at: number;
            id: string;
        }, {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                details?: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number | undefined][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                } | undefined;
                fees?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                payments?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                returns?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                records?: {
                    label: string;
                    content: string;
                }[] | undefined;
                scripts?: {
                    label: string;
                    script: string[];
                }[] | undefined;
            };
            id: string;
            created_at?: number | undefined;
        }>, "many">>;
        session: z.ZodObject<{
            secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkeys: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
            nonces: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
            scripts: z.ZodDefault<z.ZodArray<z.ZodArray<z.ZodString, "many">, "many">>;
            sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            taproot: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            txdata: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        }, "strip", z.ZodTypeAny, {
            scripts: string[][];
            secret: string;
            pubkeys: string[];
            nonces: string[];
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        }, {
            secret: string;
            pubkeys?: string[] | undefined;
            nonces?: string[] | undefined;
            scripts?: string[][] | undefined;
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        }>;
        signatures: z.ZodDefault<z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            kind: z.ZodEnum<["claim", "close", "vote"]>;
            psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }, {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }>, "many">>;
        transactions: z.ZodDefault<z.ZodArray<z.ZodObject<{
            confirmed: z.ZodBoolean;
            height: z.ZodNumber;
            kind: z.ZodEnum<["deposit", "script", "spend"]>;
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            txdata: z.ZodEffects<z.ZodString, string, string>;
            updated_at: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }, {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        members: string[];
        created_at: number;
        updated_at: number;
        title: string;
        desc: string;
        cid: string;
        agent: {
            pubkey: string;
            nonce: string;
            fees: {
                value: number;
                address: string;
                label: string;
            }[];
        };
        deposits: {
            value: number;
            txid: string;
            vout: number;
        }[];
        proposals: {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                fees: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                details: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                };
                payments: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                returns: {
                    value: number;
                    address: string;
                    label: string;
                }[];
                records: {
                    label: string;
                    content: string;
                }[];
                scripts: {
                    label: string;
                    script: string[];
                }[];
            };
            created_at: number;
            id: string;
        }[];
        session: {
            scripts: string[][];
            secret: string;
            pubkeys: string[];
            nonces: string[];
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }[];
        transactions: {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }[];
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        created_at: number;
        updated_at: number;
        title: string;
        cid: string;
        agent: {
            pubkey: string;
            nonce: string;
            fees?: {
                value: number;
                address: string;
                label: string;
            }[] | undefined;
        };
        session: {
            secret: string;
            pubkeys?: string[] | undefined;
            nonces?: string[] | undefined;
            scripts?: string[][] | undefined;
            sighash?: string | undefined;
            taproot?: string | undefined;
            txdata?: string | undefined;
        };
        members?: string[] | undefined;
        desc?: string | undefined;
        deposits?: {
            value: number;
            txid: string;
            vout: number;
        }[] | undefined;
        proposals?: {
            pubkey: string;
            sig: string;
            nonce: string;
            alias: string;
            terms: {
                details?: {
                    expires?: number | undefined;
                    quorum?: {
                        members?: [string, number | undefined][] | undefined;
                        size?: number | undefined;
                    } | undefined;
                    return?: string | undefined;
                    value?: number | undefined;
                } | undefined;
                fees?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                payments?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                returns?: {
                    value: number;
                    address: string;
                    label: string;
                }[] | undefined;
                records?: {
                    label: string;
                    content: string;
                }[] | undefined;
                scripts?: {
                    label: string;
                    script: string[];
                }[] | undefined;
            };
            id: string;
            created_at?: number | undefined;
        }[] | undefined;
        signatures?: {
            pubkey: string;
            hash: string;
            kind: "claim" | "close" | "vote";
            psig: string;
        }[] | undefined;
        transactions?: {
            txid: string;
            txdata: string;
            kind: "script" | "deposit" | "spend";
            confirmed: boolean;
            height: number;
            updated_at: number;
        }[] | undefined;
    }>;
    members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    template: z.ZodObject<{
        title: z.ZodString;
        desc: z.ZodDefault<z.ZodString>;
        members: z.ZodDefault<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    }, "strip", z.ZodTypeAny, {
        members: string[];
        title: string;
        desc: string;
    }, {
        title: string;
        desc?: string | undefined;
        members?: string[] | undefined;
    }>;
};
export {};
//# sourceMappingURL=contract.d.ts.map